@@ -1,5 +1,3 @@
-extern uint CRCTab[256];
-
 void CryptData::SetKey13(const char *Password)
 {
   Key13[0]=Key13[1]=Key13[2]=0;
@@ -25,22 +23,11 @@ void CryptData::SetKey15(const char *Password)
   {
     byte P=Password[I];
     Key15[2]^=P^CRCTab[P];
-    Key15[3]+=P+(CRCTab[P]>>16);
+    Key15[3]+=ushort(P+(CRCTab[P]>>16));
   }
 }
 
 
-void CryptData::SetAV15Encryption()
-{
-  InitCRC32(CRCTab);
-  Method=CRYPT_RAR15;
-  Key15[0]=0x4765;
-  Key15[1]=0x9021;
-  Key15[2]=0x7382;
-  Key15[3]=0x5215;
-}
-
-
 void CryptData::SetCmt13Encryption()
 {
   Method=CRYPT_RAR13;
@@ -68,7 +55,7 @@ void CryptData::Crypt15(byte *Data,size_t Count)
   {
     Key15[0]+=0x1234;
     Key15[1]^=CRCTab[(Key15[0] & 0x1fe)>>1];
-    Key15[2]-=CRCTab[(Key15[0] & 0x1fe)>>1]>>16;
+    Key15[2]-=ushort(CRCTab[(Key15[0] & 0x1fe)>>1]>>16);
     Key15[0]^=Key15[2];
     Key15[3]=rotrs(Key15[3]&0xffff,1,16)^Key15[1];
     Key15[3]=rotrs(Key15[3]&0xffff,1,16);
